package Potentiometers "Package containing example models exploring the use of potentiometers"
  package Components "Package containing the component used in the example models"
    extends Modelica.Icons.Package;

    model ThumbwheelPotentiometer "Potentiometer controlled by a thumbwheel"
      extends Modelica.Electrical.Analog.Interfaces.TwoPin;
      Modelica.Electrical.Analog.Interfaces.Pin wiper_pin "Potentiometer wiper terminal." annotation(Placement(visible = true, transformation(origin = {0, -105}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.VariableResistor R1 "Resistance between positive pin and wiper." annotation(Placement(visible = true, transformation(origin = {-30, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.VariableResistor R2 "Resistance between negative pin and wiper." annotation(Placement(visible = true, transformation(origin = {30, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(Placement(visible = true, transformation(origin = {-80, 105}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.IdealGearR2T R2T(ratio = 1) "Converter of angle to translational position." annotation(Placement(visible = true, transformation(origin = {0, 80}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      constant Real lengthPerUnitAngle(unit = "m/rad") = 1;
      Modelica.Mechanics.Translational.Components.MassWithStopAndFriction stop(L = 0, smin = (minAngle - (maxAngle - minAngle) * 0.01) * lengthPerUnitAngle, m.displayUnit = "g", m = 1e-05, F_prop = 0, F_Coulomb = 0, F_Stribeck = 0, smax = (maxAngle + (maxAngle - minAngle) * 0.01) * lengthPerUnitAngle, fexp = 1) "Boundry of the thumbwheel." annotation(Placement(visible = true, transformation(origin = {0, 50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor pos "Position sensor of the thumbwheel." annotation(Placement(visible = true, transformation(origin = {0, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant minPhi(k = minAngle) "Constant signal with minimum angle." annotation(Placement(visible = true, transformation(origin = {-70, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Modelica.Units.SI.Angle minAngle = 0 "Minimum angle for the thumbwheel";
      parameter Modelica.Units.SI.Angle maxAngle = 3.14159265358979 "Maximum angle for the thumbwheel";
      parameter Modelica.Units.SI.Resistance minRes = 10 "Minimum resistance for the potentiometer";
      parameter Modelica.Units.SI.Resistance maxRes(displayUnit = "kOhm") = 1000 "Maximum resistance for the potentiometer";
      Modelica.Blocks.Math.Add p_add(k1 = (maxRes - minRes) / (maxAngle - minAngle)) "Position map to resistance." annotation(Placement(visible = true, transformation(origin = {-30, -50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add n_add(k2 = (maxRes - minRes) / (maxAngle - minAngle)) "Position map to resistance." annotation(Placement(visible = true, transformation(origin = {30, -50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add minAdd "Minimum position compared to potentiometer position." annotation(Placement(visible = true, transformation(origin = {-15, -15}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add maxAdd(k2 = -1) "Maximum position compared to potentiometer position." annotation(Placement(visible = true, transformation(origin = {15, -15}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant maxPhi(k = maxAngle) "Constant signal with maximum angle." annotation(Placement(visible = true, transformation(origin = {70, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant minResistance(k = minRes) "Constant signal with minimum resistance." annotation(Placement(visible = true, transformation(origin = {-70, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.SpringDamper springDamper1(c = 1000, d = 10, phi_rel.start = 0, phi_rel.fixed = true, w_rel.start = 0, w_rel.fixed = true) annotation(Placement(visible = true, transformation(origin = {-50, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(p, R1.p) annotation(Line(visible = true, origin = {-82.5, -30}, points = {{-17.5, 30}, {2.5, 30}, {2.5, -50}, {42.5, -50}}, color = {10, 90, 224}));
      connect(R1.n, wiper_pin) annotation(Line(visible = true, origin = {-6.667, -88.333}, points = {{-13.333, 8.333}, {6.667, 8.333}, {6.667, -16.667}}, color = {10, 90, 224}));
      connect(R2.p, wiper_pin) annotation(Line(visible = true, origin = {6.667, -88.333}, points = {{13.333, 8.333}, {-6.667, 8.333}, {-6.667, -16.667}}, color = {10, 90, 224}));
      connect(R2.n, n) annotation(Line(visible = true, origin = {82.5, -30}, points = {{-42.5, -50}, {-2.5, -50}, {-2.5, 30}, {17.5, 30}}, color = {10, 90, 224}));
      connect(R2T.flangeT, stop.flange_a) annotation(Line(visible = true, origin = {0, 65}, points = {{0, 5}, {0, -5}}, color = {0, 127, 0}));
      connect(stop.flange_b, pos.flange) annotation(Line(visible = true, origin = {0, 35}, points = {{0, 5}, {0, -5}}, color = {0, 127, 0}));
      connect(p_add.y, R1.R) annotation(Line(visible = true, origin = {-30, -65}, points = {{0, 4}, {0, -4}}, color = {1, 37, 163}));
      connect(n_add.y, R2.R) annotation(Line(visible = true, origin = {30, -65}, points = {{0, 4}, {0, -4}}, color = {1, 37, 163}));
      connect(pos.s, minAdd.u1) annotation(Line(visible = true, origin = {-6, 0}, points = {{6, 9}, {6, 0}, {-3, 0}, {-3, -3}}, color = {1, 37, 163}));
      connect(pos.s, maxAdd.u2) annotation(Line(visible = true, origin = {6, 0}, points = {{-6, 9}, {-6, 0}, {3, 0}, {3, -3}}, color = {1, 37, 163}));
      connect(maxPhi.y, maxAdd.u1) annotation(Line(visible = true, origin = {33.667, 25.667}, points = {{25.333, 14.333}, {-12.667, 14.333}, {-12.667, -28.667}}, color = {1, 37, 163}));
      connect(minPhi.y, minAdd.u2) annotation(Line(visible = true, origin = {-33.667, 39}, points = {{-25.333, 21}, {12.667, 21}, {12.667, -42}}, color = {1, 37, 163}));
      connect(minAdd.y, p_add.u1) annotation(Line(visible = true, origin = {-21, -37.375}, points = {{6, 11.375}, {6, 2.375}, {-3, 2.375}, {-3, -0.625}}, color = {1, 37, 163}));
      connect(maxAdd.y, n_add.u2) annotation(Line(visible = true, origin = {21, -37.375}, points = {{-6, 11.375}, {-6, 2.375}, {3, 2.375}, {3, -0.625}}, color = {1, 37, 163}));
      connect(minResistance.y, p_add.u2) annotation(Line(visible = true, origin = {-45.9, -15.9}, points = {{-13.1, 35.9}, {-4.1, 35.9}, {-4.1, -14.1}, {9.9, -14.1}, {9.9, -22.1}}, color = {1, 37, 163}));
      connect(minResistance.y, n_add.u1) annotation(Line(visible = true, origin = {-17.7, -15.9}, points = {{-41.3, 35.9}, {-32.3, 35.9}, {-32.3, -14.1}, {53.7, -14.1}, {53.7, -22.1}}, color = {1, 37, 163}));
      connect(flange_a, springDamper1.flange_a) annotation(Line(visible = true, origin = {-73.333, 95}, points = {{-6.667, 10}, {-6.667, -5}, {13.333, -5}}, color = {64, 64, 64}));
      connect(springDamper1.flange_b, R2T.flangeR) annotation(Line(visible = true, origin = {-20, 94}, points = {{-20, -4}, {-10, -4}, {-10, 6}, {20, 6}, {20, -4}}, color = {64, 64, 64}));
      annotation(Documentation(info = "<html><div>
<div>Potentiometer controlled by a thumbwheel. The model consists of two variable resistors, to total resistance of which equal the parameter maxRes. When the thumbhweel is turned all the way to the left, almost all of the total resistance will be present between the right resistor and the wiper pin. This model represents a potentiometer where the wiper pin is slided along a material whose resistance is lineraly proportional to its length. By turning the thumbwheel to the right, the distance between the positive pin and the wiper becomes larger and the resistance between them increases lineraly.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {0, 0, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-70, -30}, {70, 30}}), Ellipse(visible = true, origin = {0, 30}, lineColor = {0, 0, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-50, -50}, {50, 50}}), Line(visible = true, origin = {-80, 0}, points = {{-10, 0}, {10, 0}}, color = {0, 0, 255}), Line(visible = true, origin = {80, 0}, points = {{-10, 0}, {10, 0}}, color = {0, 0, 255}), Line(visible = true, origin = {0, -60.946}, points = {{0, -30.946}, {0, 30.946}}, color = {0, 0, 255})}), Diagram(coordinateSystem(extent = {{-100, -105}, {100, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end ThumbwheelPotentiometer;

    model SlidingPotentiometer "Potentiometer controlled by a slider"
      extends Modelica.Electrical.Analog.Interfaces.TwoPin;
      Modelica.Electrical.Analog.Interfaces.Pin wiper_pin "Potentiometer wiper terminal." annotation(Placement(visible = true, transformation(origin = {0, -105}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.VariableResistor R1 "Resistance between positive pin and wiper." annotation(Placement(visible = true, transformation(origin = {-30, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.VariableResistor R2 "Resistance between negative pin and wiper." annotation(Placement(visible = true, transformation(origin = {30, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.MassWithStopAndFriction stop(L = 0, smax = maxPos + (maxPos - minPos) * 0.01, smin = minPos - Modelica.Constants.small, m.displayUnit = "g", m = 1e-05, F_prop = 0, F_Coulomb = 0, F_Stribeck = 0) "Boundry of the slider." annotation(Placement(visible = true, transformation(origin = {0, 50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Mechanics.Translational.Sensors.PositionSensor pos "Position sensor of the slider." annotation(Placement(visible = true, transformation(origin = {0, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant minS(k = minPos) "Constant signal with minimum position." annotation(Placement(visible = true, transformation(origin = {-70, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Modelica.Units.SI.Length minPos = 0 "Minimum angle for the thumbwheel.";
      parameter Modelica.Units.SI.Length maxPos(displayUnit = "cm") = 0.1 "Maximum angle for the thumbwheel.";
      parameter Modelica.Units.SI.Resistance minRes = 10 "Minimum resistance for the potentiometer.";
      parameter Modelica.Units.SI.Resistance maxRes(displayUnit = "kOhm") = 1000 "Maximum resistance for the potentiometer.";
      Modelica.Blocks.Math.Add p_add(k1 = (maxRes - minRes) / (maxPos - minPos)) "Position map to resistance." annotation(Placement(visible = true, transformation(origin = {-30, -50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add n_add(k2 = (maxRes - minRes) / (maxPos - minPos)) "Position map to resistance." annotation(Placement(visible = true, transformation(origin = {30, -50}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add minAdd "Minimum position compared to potentiometer position." annotation(Placement(visible = true, transformation(origin = {-15, -15}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add maxAdd(k2 = -1) "Maximum position compared to potentiometer position." annotation(Placement(visible = true, transformation(origin = {15, -15}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant maxS(k = maxPos) "Constant signal with maximum positon." annotation(Placement(visible = true, transformation(origin = {70, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant minResistance(k = minRes) "Constant signal with minimum resistance." annotation(Placement(visible = true, transformation(origin = {-70, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Interfaces.Flange_a flange_a annotation(Placement(visible = true, transformation(origin = {0, 105}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.SpringDamper springDamper1(c = 1000, d = 10, s_rel.start = 0, s_rel.fixed = true, v_rel.start = 0, v_rel.fixed = true) annotation(Placement(visible = true, transformation(origin = {0, 80}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    equation
      connect(p, R1.p) annotation(Line(visible = true, origin = {-82.5, -30}, points = {{-17.5, 30}, {2.5, 30}, {2.5, -50}, {42.5, -50}}, color = {10, 90, 224}));
      connect(R1.n, wiper_pin) annotation(Line(visible = true, origin = {-6.667, -88.333}, points = {{-13.333, 8.333}, {6.667, 8.333}, {6.667, -16.667}}, color = {10, 90, 224}));
      connect(R2.p, wiper_pin) annotation(Line(visible = true, origin = {6.667, -88.333}, points = {{13.333, 8.333}, {-6.667, 8.333}, {-6.667, -16.667}}, color = {10, 90, 224}));
      connect(R2.n, n) annotation(Line(visible = true, origin = {82.5, -30}, points = {{-42.5, -50}, {-2.5, -50}, {-2.5, 30}, {17.5, 30}}, color = {10, 90, 224}));
      connect(stop.flange_b, pos.flange) annotation(Line(visible = true, origin = {0, 35}, points = {{0, 5}, {0, -5}}, color = {0, 127, 0}));
      connect(p_add.y, R1.R) annotation(Line(visible = true, origin = {-30, -65}, points = {{0, 4}, {0, -4}}, color = {1, 37, 163}));
      connect(n_add.y, R2.R) annotation(Line(visible = true, origin = {30, -65}, points = {{0, 4}, {0, -4}}, color = {1, 37, 163}));
      connect(pos.s, minAdd.u1) annotation(Line(visible = true, origin = {-6, 0}, points = {{6, 9}, {6, 0}, {-3, 0}, {-3, -3}}, color = {1, 37, 163}));
      connect(pos.s, maxAdd.u2) annotation(Line(visible = true, origin = {6, 0}, points = {{-6, 9}, {-6, 0}, {3, 0}, {3, -3}}, color = {1, 37, 163}));
      connect(maxS.y, maxAdd.u1) annotation(Line(visible = true, origin = {33.667, 25.667}, points = {{25.333, 14.333}, {-12.667, 14.333}, {-12.667, -28.667}}, color = {1, 37, 163}));
      connect(minS.y, minAdd.u2) annotation(Line(visible = true, origin = {-33.667, 39}, points = {{-25.333, 21}, {12.667, 21}, {12.667, -42}}, color = {1, 37, 163}));
      connect(minAdd.y, p_add.u1) annotation(Line(visible = true, origin = {-21, -37.375}, points = {{6, 11.375}, {6, 2.375}, {-3, 2.375}, {-3, -0.625}}, color = {1, 37, 163}));
      connect(maxAdd.y, n_add.u2) annotation(Line(visible = true, origin = {21, -37.375}, points = {{-6, 11.375}, {-6, 2.375}, {3, 2.375}, {3, -0.625}}, color = {1, 37, 163}));
      connect(minResistance.y, p_add.u2) annotation(Line(visible = true, origin = {-45.9, -15.9}, points = {{-13.1, 35.9}, {-4.1, 35.9}, {-4.1, -14.1}, {9.9, -14.1}, {9.9, -22.1}}, color = {1, 37, 163}));
      connect(minResistance.y, n_add.u1) annotation(Line(visible = true, origin = {-17.7, -15.9}, points = {{-41.3, 35.9}, {-32.3, 35.9}, {-32.3, -14.1}, {53.7, -14.1}, {53.7, -22.1}}, color = {1, 37, 163}));
      connect(flange_a, springDamper1.flange_a) annotation(Line(visible = true, origin = {0, 97.5}, points = {{-0, 7.5}, {0, -7.5}}, color = {0, 127, 0}));
      connect(springDamper1.flange_b, stop.flange_a) annotation(Line(visible = true, origin = {0, 65}, points = {{0, 5}, {-0, -5}}, color = {0, 127, 0}));
      annotation(Documentation(info = "<html><div>
<div>Potentiometer controlled by a slider. The model consists of two variable resistors, to total resistance of which equal the parameter maxRes. When the slider is positioned all the way to the left, almost all of the total resistance will be present between the right resistor and the wiper pin. This model represents a potentiometer where the wiper pin is slided along a material whose resistance is lineraly proportional to its length. By positioning the slider to the right, the distance between the positive pin and the wiper becomes larger and the resistance between them increases lineraly.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {0, 0, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-70, -30}, {70, 30}}), Line(visible = true, origin = {-80, 0}, points = {{-10, 0}, {10, 0}}, color = {0, 0, 255}), Line(visible = true, origin = {80, 0}, points = {{-10, 0}, {10, 0}}, color = {0, 0, 255}), Line(visible = true, origin = {0, -60.946}, points = {{0, -30.946}, {0, 30.946}}, color = {0, 0, 255}), Line(visible = true, origin = {-10, 35.714}, points = {{-60, -5.714}, {80, -5.714}, {80, 14.286}, {60, -5.714}, {-40, -5.714}, {-60, 14.286}, {-60, -5.714}}, color = {0, 127, 0})}), Diagram(coordinateSystem(extent = {{-100, -105}, {100, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end SlidingPotentiometer;
    annotation(Documentation(info = "<html></html>"), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end Components;

  model ThumbwheelPotentiometerExample "Thumbwheel potentiometer in normal configuration"
    extends Modelica.Icons.Example;
    Potentiometers.Components.ThumbwheelPotentiometer potentionmeter(maxRes.displayUnit = "kOhm", maxRes = maxRes, minAngle = minAngle, maxAngle = maxAngle, minRes = minRes) "Thumbwheel potentiometer in rheostat configuration." annotation(Placement(visible = true, transformation(origin = {30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Basic.Ground ground "Ground component." annotation(Placement(visible = true, transformation(origin = {-20, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Sources.Position position "Angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Sources.ConstantVoltage source(V = 5) "Constant voltage source." annotation(Placement(visible = true, transformation(origin = {-20, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.Ramp angleSignal(height = 3.14, duration = 8) "Ramp signal that sets the angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-80, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Modelica.Units.SI.Angle minAngle = 0 "Minimum angle for the thumbwheel";
    parameter Modelica.Units.SI.Angle maxAngle = 3.14159265358979 "Maximum angle for the thumbwheel";
    parameter Modelica.Units.SI.Resistance minRes = 10 "Minimum resistance for the potentiometer";
    parameter Modelica.Units.SI.Resistance maxRes(displayUnit = "kOhm") = 1000 "Maximum resistance for the potentiometer";
    Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor annotation(Placement(visible = true, transformation(origin = {30, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Electrical.Analog.Basic.Ground ground1 "Ground component." annotation(Placement(visible = true, transformation(origin = {30, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Nonlinear.Limiter limiter(uMax = maxAngle, uMin = minAngle) annotation(Placement(visible = true, transformation(origin = {-40, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(source.n, ground.p) annotation(Line(visible = true, origin = {-20, -50}, points = {{0, 10}, {0, -10}}, color = {10, 90, 224}));
    connect(potentionmeter.flange_a, position.flange) annotation(Line(visible = true, origin = {23.333, 21}, points = {{6.667, -18}, {6.667, 9}, {-13.333, 9}}, color = {64, 64, 64}));
    connect(potentionmeter.p, source.p) annotation(Line(visible = true, origin = {-6.667, -6.667}, points = {{26.667, 6.667}, {-13.333, 6.667}, {-13.333, -13.333}}, color = {10, 90, 224}));
    connect(potentionmeter.n, ground.p) annotation(Line(visible = true, origin = {32.5, -30}, points = {{7.5, 30}, {27.5, 30}, {27.5, -30}, {-52.5, -30}}, color = {10, 90, 224}));
    connect(potentionmeter.wiper_pin, voltageSensor.p) annotation(Line(visible = true, origin = {30, -15}, points = {{0, 5}, {0, -5}}, color = {10, 90, 224}));
    connect(voltageSensor.n, ground1.p) annotation(Line(visible = true, origin = {30, -55}, points = {{0, 15}, {0, -15}}, color = {10, 90, 224}));
    connect(angleSignal.y, limiter.u) annotation(Line(visible = true, origin = {-60.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(limiter.y, position.phi_ref) annotation(Line(visible = true, origin = {-20.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    annotation(preferredView = "info", __Wolfram, experiment(StopTime = 10, __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html>
<p>Potentiometers, also knows as pots, are useful electrical components that allows a person or a machine to directly tune the voltage or restiance in one part of a circuit. In its normal configuration, a potentiometer acts as a variable voltage divider. If a voltage source is connected between the two pins called terminals, the voltage over the third pin, known as the wiper will vary with the position of the potentiometer shaft. This shaft can for example be controlled by a slider or a thumbwheel.</p>

<h4>Model</h4>

<p>In this example model, a thumbwheel controlled potentiometer has been connected in its normal configuration. The angular position of the thumbwheel will be increased following a ramp signal, from 0 to 180 degrees. The voltage on the wiper pin is measured with a <a href=\"modelica://Modelica.Electrical.Analog.Sensors.VoltageSensor\">voltage sensor</a>.</p>

<h4>Simulation</h4>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Potentiometers.ThumbwheelPotentiometerExample/./DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>


<h4>Plot the results</h4>

<p>Explore how the voltage on the wiper pin decreases as the potentiometer gets turned around. Plot the Model plot called Potentiometer voltages by double clicking it from the Model Plots section.</p>

<p>You should now see the graph below:</p>


<p style=\"text-align: center;\"><img src=\"modelica://Potentiometers.ThumbwheelPotentiometerExample/./DocumentationFiles/plot1.png\" style=\"width:600px\" alt=\"\" /></p>
</html>", figures = {Figure(title = "Thumbwheel angle", identifier = "03d9a", preferred = true, plots = {Plot(curves = {Curve(y = position.phi, legend = "Thumbwheel Angle"), Curve(y = minAngle, legend = "Min Angle"), Curve(y = maxAngle, legend = "Max Angle")})}), Figure(title = "Potentiometer resistances", identifier = "4656a", plots = {Plot(curves = {Curve(y = potentionmeter.R1.R, legend = "Positive Pin Resistance"), Curve(y = potentionmeter.R2.R, legend = "Negative Pin Resistance"), Curve(y = potentionmeter.minRes, legend = "Min Resistance"), Curve(y = potentionmeter.maxRes, legend = "Max Resistance")})}), Figure(title = "Potentiometer currents", identifier = "ee923", plots = {Plot(curves = {Curve(y = potentionmeter.p.i, legend = "Positive Pin"), Curve(y = potentionmeter.n.i, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.i, legend = "Wiper Pin")}, y = Axis(unit = "mA", label = "Pin Currents"))}), Figure(title = "Potentiometer voltages", identifier = "81c9c", preferred = true, plots = {Plot(curves = {Curve(y = potentionmeter.p.v, legend = "Positive Pin"), Curve(y = potentionmeter.n.v, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.v, legend = "Wiper Pin")}, y = Axis(label = "Pin Voltages"))})}), Diagram(coordinateSystem(extent = {{-100, -95}, {100, 55}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end ThumbwheelPotentiometerExample;

  model SlidingPotentiometerExample "Sliding potentiometer in normal configuration"
    extends Modelica.Icons.Example;
    Components.SlidingPotentiometer potentionmeter(maxRes.displayUnit = "kOhm", maxRes = maxRes, minRes = minRes, minPos = minPos, maxPos = maxPos) "Thumbwheel potentiometer in rheostat configuration." annotation(Placement(visible = true, transformation(origin = {30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Basic.Ground ground "Ground component." annotation(Placement(visible = true, transformation(origin = {-30, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Sources.ConstantVoltage source(V = 5) "Constant voltage source." annotation(Placement(visible = true, transformation(origin = {-30, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.Ramp angleSignal(height = 0.1, duration = 8) "Ramp signal that sets the angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-80, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Modelica.Units.SI.Length minPos = 0 "Minimum angle for the thumbwheel.";
    parameter Modelica.Units.SI.Length maxPos(displayUnit = "cm") = 0.1 "Maximum angle for the thumbwheel.";
    parameter Modelica.Units.SI.Resistance minRes = 10 "Minimum resistance for the potentiometer.";
    parameter Modelica.Units.SI.Resistance maxRes(displayUnit = "kOhm") = 1000 "Maximum resistance for the potentiometer.";
    Modelica.Electrical.Analog.Sensors.VoltageSensor voltageSensor annotation(Placement(visible = true, transformation(origin = {30, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Electrical.Analog.Basic.Ground ground1 "Ground component." annotation(Placement(visible = true, transformation(origin = {30, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Translational.Sources.Position position annotation(Placement(visible = true, transformation(origin = {0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Nonlinear.Limiter limiter(uMax = maxPos, uMin = minPos) annotation(Placement(visible = true, transformation(origin = {-40, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(source.n, ground.p) annotation(Line(visible = true, origin = {-30, -50}, points = {{0, 10}, {0, -10}}, color = {10, 90, 224}));
    connect(potentionmeter.p, source.p) annotation(Line(visible = true, origin = {-13.333, -6.667}, points = {{33.333, 6.667}, {-16.667, 6.667}, {-16.667, -13.333}}, color = {10, 90, 224}));
    connect(potentionmeter.n, ground.p) annotation(Line(visible = true, origin = {32.5, -30}, points = {{7.5, 30}, {27.5, 30}, {27.5, -30}, {-62.5, -30}}, color = {10, 90, 224}));
    connect(potentionmeter.wiper_pin, voltageSensor.p) annotation(Line(visible = true, origin = {30, -15}, points = {{0, 5}, {0, -5}}, color = {10, 90, 224}));
    connect(voltageSensor.n, ground1.p) annotation(Line(visible = true, origin = {30, -55}, points = {{0, 15}, {0, -15}}, color = {10, 90, 224}));
    connect(position.flange, potentionmeter.flange_a) annotation(Line(visible = true, origin = {23.333, 21.333}, points = {{-13.333, 8.667}, {6.667, 8.667}, {6.667, -17.333}}, color = {0, 127, 0}));
    connect(limiter.y, position.s_ref) annotation(Line(visible = true, origin = {-20.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(limiter.u, angleSignal.y) annotation(Line(visible = true, origin = {-60.5, 30}, points = {{8.5, 0}, {-8.5, 0}}, color = {1, 37, 163}));
    annotation(preferredView = "info", __Wolfram, experiment(StopTime = 10, __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html>
<p>Potentiometers, also knows as pots, are useful electrical components that allows a person or a machine to directly tune the voltage or restiance in one part of a circuit. In its normal configuration, a potentiometer acts as a variable voltage divider. If a voltage source is connected between the two pins called terminals, the voltage over the third pin, known as the wiper will vary with the position of the potentiometer shaft. This shaft can for example be controlled by a slider or a thumbwheel.</p>

<h4>Model</h4>

<p>In this example model, a slider controlled potentiometer has been connected in its normal configuration. The translational position of the slider will be increased following a ramp signal, from 0 to 10 centimeter (about 4 inches). The voltage on the wiper pin is measured with a <a href=\"modelica://Modelica.Electrical.Analog.Sensors.VoltageSensor\">voltage sensor</a>.</p>

<h4>Simulation</h4>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Potentiometers/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<h4>Plot the results</h4>

<p>Explore how the voltage on the wiper pin decreases as the potentiometer gets turned around. Plot the Model plot called Potentiometer voltages by double clicking it from the Model Plots section.</p>

<p>You should now see the graph below:</p>


<p style=\"text-align: center;\"><img src=\"modelica://Potentiometers.SlidingPotentiometerExample/./DocumentationFiles/plot2.png\" style=\"width:600px\" alt=\"\" /></p>
</html>", figures = {Figure(title = "Slider position", identifier = "063bc", preferred = true, plots = {Plot(curves = {Curve(y = position.s, legend = "Slider Position"), Curve(y = minPos, legend = "Min Position"), Curve(y = maxPos, legend = "Max Position")})}), Figure(title = "Potentiometer resistances", identifier = "6e941", plots = {Plot(curves = {Curve(y = potentionmeter.R1.R, legend = "Positive Pin Resistance"), Curve(y = potentionmeter.R2.R, legend = "Negative Pin Resistance"), Curve(y = potentionmeter.minRes, legend = "Min Resistance"), Curve(y = potentionmeter.maxRes, legend = "Max Resistance")})}), Figure(title = "Potentiometer currents", identifier = "7ee3e", plots = {Plot(curves = {Curve(y = potentionmeter.p.i, legend = "Positive Pin"), Curve(y = potentionmeter.n.i, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.i, legend = "Wiper Pin")}, y = Axis(unit = "mA", label = "Pin Currents"))}), Figure(title = "Potentiometer voltages", identifier = "4834d", preferred = true, plots = {Plot(curves = {Curve(y = potentionmeter.p.v, legend = "Positive Pin"), Curve(y = potentionmeter.n.v, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.v, legend = "Wiper Pin")}, y = Axis(label = "Pin Voltages"))})}), Diagram(coordinateSystem(extent = {{-100, -95}, {100, 60}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end SlidingPotentiometerExample;

  model RheostatConfiguration "Thumbwheel potentiometer in rheostat configuration"
    extends Modelica.Icons.Example;
    Components.ThumbwheelPotentiometer potentionmeter(maxRes.displayUnit = "kOhm", maxRes = maxRes, minAngle = minAngle, maxAngle = maxAngle, minRes = minRes) "Thumbwheel potentiometer in rheostat configuration." annotation(Placement(visible = true, transformation(origin = {30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Basic.Ground ground "Ground component." annotation(Placement(visible = true, transformation(origin = {-30, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Sources.Position position "Angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Sources.ConstantVoltage source(V = 5) "Constant voltage source." annotation(Placement(visible = true, transformation(origin = {-30, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.Ramp angleSignal(height = 3.14, duration = 8) "Ramp signal that sets the angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-80, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Modelica.Units.SI.Angle minAngle = 0 "Minimum angle for the thumbwheel.";
    parameter Modelica.Units.SI.Angle maxAngle = 3.14159265358979 "Maximum angle for the thumbwheel.";
    parameter Modelica.Units.SI.Resistance minRes = 10 "Minimum resistance for the potentiometer.";
    parameter Modelica.Units.SI.Resistance maxRes(displayUnit = "kOhm") = 1000 "Maximum resistance for the potentiometer.";
    Modelica.Blocks.Nonlinear.Limiter limiter(uMax = maxAngle, uMin = minAngle) annotation(Placement(visible = true, transformation(origin = {-40, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(source.n, ground.p) annotation(Line(visible = true, origin = {-30, -50}, points = {{0, 10}, {0, -10}}, color = {10, 90, 224}));
    connect(potentionmeter.flange_a, position.flange) annotation(Line(visible = true, origin = {23.333, 21}, points = {{6.667, -18}, {6.667, 9}, {-13.333, 9}}, color = {64, 64, 64}));
    connect(potentionmeter.p, source.p) annotation(Line(visible = true, origin = {-13.333, -6.667}, points = {{33.333, 6.667}, {-16.667, 6.667}, {-16.667, -13.333}}, color = {10, 90, 224}));
    connect(potentionmeter.wiper_pin, ground.p) annotation(Line(visible = true, origin = {16.802, -43.333}, points = {{13.198, 33.333}, {13.401, -16.667}, {-46.802, -16.667}}, color = {10, 90, 224}));
    connect(potentionmeter.n, potentionmeter.wiper_pin) annotation(Line(visible = true, origin = {48.081, -10}, points = {{-8.081, 10}, {21.919, 10}, {21.919, -10}, {-17.878, -10}, {-18.081, 0}}, color = {10, 90, 224}));
    connect(angleSignal.y, limiter.u) annotation(Line(visible = true, origin = {-60.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(limiter.y, position.phi_ref) annotation(Line(visible = true, origin = {-20.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    annotation(preferredView = "info", __Wolfram, experiment(StopTime = 10, __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html>
<p>Potentiometers, also knows as pots, are useful electrical components that allows a person or a machine to directly tune the voltage or restiance in one part of a circuit. In its normal configuration, a potentiometer acts as a variable voltage divider. If a voltage source is connected between the two pins called terminals, the voltage over the third pin, known as the wiper will vary with the position of the potentiometer shaft. This shaft can for example be controlled by a slider or a thumbwheel.</p>

<h4>Model</h4>

<p>In this example model, a thumbwheel potentiometer has been connected in a rheostat configuration, working as a variable resistor. The terminal pin connected to the ground has been short-circuited with the wiper pin. This means that the voltage over the terminal to the wiper will be the same as over the two terminals. When no other components are connected in a series, the voltage will be same as the input voltage.</p>

<p>The current flowing from the input terminal to the wiper will however depend on the angle of the thumbwheel, hence its use as a variable resistor.</p>

<h4>Simulation</h4>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Potentiometers/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<h4>Plot the results</h4>

<p>Explore how the current through the rheostat decreases as the potentiometer gets turned around. Plot the Model plot called Potentiometer currents by double clicking it from the Model Plots section.</p>

<p>You should now see the graph below:</p>


<p style=\"text-align: center;\"><img src=\"modelica://Potentiometers.RheostatConfiguration/./DocumentationFiles/plot.png\" style=\"width:600px\" alt=\"\" /></p>
</html>", figures = {Figure(title = "Thumbwheel angle", identifier = "eb76a", preferred = true, plots = {Plot(curves = {Curve(y = position.phi, legend = "Thumbwheel Angle"), Curve(y = minAngle, legend = "Min Angle"), Curve(y = maxAngle, legend = "Max Angle")})}), Figure(title = "Potentiometer resistances", identifier = "fd301", plots = {Plot(curves = {Curve(y = potentionmeter.R1.R, legend = "Positive Pin Resistance"), Curve(y = potentionmeter.R2.R, legend = "Negative Pin Resistance"), Curve(y = potentionmeter.minRes, legend = "Min Resistance"), Curve(y = potentionmeter.maxRes, legend = "Max Resistance")}, y = Axis(unit = "Ohm"))}), Figure(title = "Potentiometer currents", identifier = "d4528", preferred = true, plots = {Plot(curves = {Curve(y = potentionmeter.p.i, legend = "Positive Pin"), Curve(y = potentionmeter.n.i, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.i, legend = "Wiper Pin")}, y = Axis(label = "Pin Currents"))}), Figure(title = "Potentiometer voltages", identifier = "78c4c", plots = {Plot(curves = {Curve(y = potentionmeter.p.v, legend = "Positive Pin"), Curve(y = potentionmeter.n.v, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.v, legend = "Wiper Pin")}, y = Axis(label = "Pin Voltages"))})}), Diagram(coordinateSystem(extent = {{-100, -90}, {100, 60}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end RheostatConfiguration;

  model RheostatMotorControl "Motor controlled by a thumbwheel potentiometer in rheostat configuration"
    extends Modelica.Icons.Example;
    Potentiometers.Components.ThumbwheelPotentiometer potentionmeter(maxRes.displayUnit = "kOhm", maxRes = maxRes, minAngle = minAngle, maxAngle = maxAngle, minRes = minRes) "Thumbwheel potentiometer in rheostat configuration." annotation(Placement(visible = true, transformation(origin = {30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Basic.Ground ground "Ground component." annotation(Placement(visible = true, transformation(origin = {-30, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Sources.Position position "Angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Sources.ConstantVoltage source(V = 5) "Constant voltage source." annotation(Placement(visible = true, transformation(origin = {-30, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Blocks.Sources.Trapezoid angleSignal(amplitude = -3.14, rising = 8, width = 2, falling = 8, period = 20, offset = 3.14) "Trapezoid signal that sets the angle of the thumbwheel potentiometer." annotation(Placement(visible = true, transformation(origin = {-80, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Modelica.Units.SI.Angle minAngle = 0 "Minimum angle for the thumbwheel." annotation(Dialog(group = "Potentiometer"));
    parameter Modelica.Units.SI.Angle maxAngle = 3.14159265358979 "Maximum angle for the thumbwheel." annotation(Dialog(group = "Potentiometer"));
    parameter Modelica.Units.SI.Resistance minRes = 10 "Minimum resistance for the potentiometer." annotation(Dialog(group = "Potentiometer"));
    parameter Modelica.Units.SI.Resistance maxRes(displayUnit = "kOhm") = 1000 "Maximum resistance for the potentiometer." annotation(Dialog(group = "Potentiometer"));
    Modelica.Electrical.Analog.Basic.RotationalEMF motor(k = k) "Motor controlled by rheostat." annotation(Placement(visible = true, transformation(origin = {30, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Components.Inertia inertia(J = J) "Motor inertia." annotation(Placement(visible = true, transformation(origin = {70, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Modelica.Units.SI.Inertia J = 1 "Inertia of the body driven by the motor." annotation(Dialog(group = "Motor"));
    parameter Modelica.Units.SI.ElectricalTorqueConstant k = 1 "Transformation coeffiecient of the motor." annotation(Dialog(group = "Motor"));
    Modelica.Blocks.Nonlinear.Limiter limiter(uMax = maxAngle, uMin = minAngle) annotation(Placement(visible = true, transformation(origin = {-40, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(source.n, ground.p) annotation(Line(visible = true, origin = {-30, -50}, points = {{0, 10}, {0, -10}}, color = {10, 90, 224}));
    connect(potentionmeter.flange_a, position.flange) annotation(Line(visible = true, origin = {23.333, 21}, points = {{6.667, -18}, {6.667, 9}, {-13.333, 9}}, color = {64, 64, 64}));
    connect(potentionmeter.p, source.p) annotation(Line(visible = true, origin = {-13.333, -6.667}, points = {{33.333, 6.667}, {-16.667, 6.667}, {-16.667, -13.333}}, color = {10, 90, 224}));
    connect(motor.n, ground.p) annotation(Line(visible = true, origin = {30, -50}, points = {{0, 10}, {0, -10}, {-60, -10}}, color = {10, 90, 224}));
    connect(motor.flange, inertia.flange_a) annotation(Line(visible = true, origin = {50, -30}, points = {{-10, 0}, {10, 0}}, color = {64, 64, 64}));
    connect(potentionmeter.wiper_pin, motor.p) annotation(Line(visible = true, origin = {40.135, -16.667}, points = {{-10.135, 6.667}, {-9.932, -3.333}, {-10.135, -3.333}}, color = {10, 90, 224}));
    connect(potentionmeter.n, motor.p) annotation(Line(visible = true, origin = {40, -10}, points = {{0, 10}, {10, 10}, {10, -5}, {-10, -5}, {-10, -10}}, color = {10, 90, 224}));
    connect(angleSignal.y, limiter.u) annotation(Line(visible = true, origin = {-60.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    connect(limiter.y, position.phi_ref) annotation(Line(visible = true, origin = {-20.5, 30}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
    annotation(preferredView = "info", experiment(StopTime = 20, __Wolfram_SynchronizeWithRealTime = false), __Wolfram, Documentation(info = "<html>
<p>Potentiometers, also knows as pots, are useful electrical components that allows a person or a machine to directly tune the voltage or restiance in one part of a circuit. In its normal configuration, a potentiometer acts as a variable voltage divider. If a voltage source is connected between the two pins called terminals, the voltage over the third pin, known as the wiper will vary with the position of the potentiometer shaft. This shaft can for example be controlled by a slider or a thumbwheel.</p>

<h4>Model</h4>

<p>In this example model, a thumbwheel potentiometer has been connected in a rheostat configuration, working as a variable resistor. The terminal pin connected to the ground has been short-circuited with the wiper pin. This means that the voltage over the terminal to the wiper will be the same as over the two terminals. The rheostat has been connected in a series with a motor. The motor in turn drives a body with inertia.</p>

<p>The torque produced by the motor will be proportional to the current running through the motor. Since the motor is connected in a series with the potentiometer, the current throught the motor will be the same as the current through the potentiometer. By turning the potentiometer the motor torque can be controlled.</p>

<h4>Simulation</h4>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Potentiometers/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<h4>Plot the results</h4>

<p>Explore how the torque from the motor increases as the thumbwheel is turned. Plot the Model plot called Motor torque by double clicking it from the Model Plots section.</p>

<p>You should now see the graph below:</p>

<p style=\"text-align: center;\"><img src=\"modelica://Potentiometers.RheostatMotorControl/./DocumentationFiles/plot3.png\" style=\"width:600px\" alt=\"\" /></p>

</div></html>", figures = {Figure(title = "Inertia states", identifier = "b04ed", preferred = true, plots = {Plot(curves = {Curve(y = inertia.phi, legend = "Angle")}), Plot(curves = {Curve(y = inertia.w, legend = "Angular Velocity")}), Plot(curves = {Curve(y = inertia.a, legend = "Acceleration")})}), Figure(title = "Motor torque", identifier = "71716", plots = {Plot(curves = {Curve(y = motor.flange.tau, legend = "Torque")}), Plot(curves = {Curve(y = position.phi, legend = "Thumbwheel Angle"), Curve(y = minAngle, legend = "Min Angle"), Curve(y = maxAngle, legend = "Max Angle")})}), Figure(title = "Thumbwheel angle", identifier = "8d2c4", plots = {Plot(curves = {Curve(y = position.phi, legend = "Thumbwheel Angle"), Curve(y = minAngle, legend = "Min Angle"), Curve(y = maxAngle, legend = "Max Angle")})}), Figure(title = "Potentiometer resistances", identifier = "8fb5c", plots = {Plot(curves = {Curve(y = potentionmeter.R1.R, legend = "Positive Pin Resistance"), Curve(y = potentionmeter.R2.R, legend = "Negative Pin Resistance"), Curve(y = potentionmeter.minRes, legend = "Min Resistance"), Curve(y = potentionmeter.maxRes, legend = "Max Resistance")}, y = Axis(unit = "Ohm"))}), Figure(title = "Potentiometer currents", identifier = "1fd20", plots = {Plot(curves = {Curve(y = potentionmeter.p.i, legend = "Positive Pin"), Curve(y = potentionmeter.n.i, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.i, legend = "Wiper Pin")}, y = Axis(label = "Pin Currents"))}), Figure(title = "Potentiometer voltages", identifier = "fdd6e", plots = {Plot(curves = {Curve(y = potentionmeter.p.v, legend = "Positive Pin"), Curve(y = potentionmeter.n.v, legend = "Negative Pin"), Curve(y = potentionmeter.wiper_pin.v, legend = "Wiper Pin")}, y = Axis(label = "Pin Voltages"))})}), Diagram(coordinateSystem(extent = {{-100, -90}, {100, 60}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end RheostatMotorControl;
  annotation(preferredView = "info", __Wolfram(openClass = Potentiometers.ThumbwheelPotentiometerExample), Documentation(info = "<html></html>"), uses(Modelica(version = "4.0.0")), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25), Text(visible = true, origin = {12.0, 20.8333}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-102.0, -70.8333}, {78.0, 29.1667}}, textString = "Ex", fontName = "Arial")}));
end Potentiometers;
